@@ -1,9 +1,10 @@
 import json
 import logging
 import cattr
+from cachetools import LRUCache
 from datetime import date, datetime
 from requests import Response, Session
-from typing import Any, Callable, Optional, Type, TypeVar, Union
+from typing import Any, Callable, MutableMapping, Optional, List, Type, TypeVar, Union
 from uuid import UUID
 
 from dapodik.utils.parser import str_to_date, str_to_datetime
@@ -17,6 +18,11 @@ class BaseDapodik(object):
         self._session = Session()
         self._base_url = base_url
         self._register_hooks()
+        self._cache: MutableMapping = LRUCache(128)
+
+    @property
+    def cache(self) -> MutableMapping:
+        return self._cache
 
     @property
     def logger(self) -> logging.Logger:
@@ -83,7 +89,13 @@ class BaseDapodik(object):
         )
         data: dict = json.loads(res.text)
         obj: Any = key(data) if callable(key) else data
-        return cattr.structure(obj, cl)
+        result = cattr.structure(obj, cl)
+        if isinstance(result, list):
+            for res in result:
+                if not hasattr(res, "_dapodik"):
+                    break
+                setattr(res, "_dapodik", self)
+        return result
 
     def _get_rest(
         self,
@@ -96,12 +108,14 @@ class BaseDapodik(object):
         prefix: str = "rest/",
         key: Callable[[Any], Any] = lambda x: x["rows"],
     ) -> T:
-        query = query or {
+        params = {
             "page": page,
             "start": start,
             "limit": limit,
         }
-        return self._get_rows(prefix + path.lstrip("/"), cl=cl, query=query, key=key)
+        if query:
+            params.update(query)
+        return self._get_rows(prefix + path.lstrip("/"), cl=cl, query=params, key=key)
 
     def _query(self, *args, **kwargs) -> dict:
         query = dict()
@@ -114,3 +128,9 @@ class BaseDapodik(object):
         cattr.register_structure_hook(date, lambda d, t: str_to_date(d))
         cattr.register_structure_hook(datetime, lambda d, t: str_to_datetime(d))
         cattr.register_structure_hook(UUID, lambda d, t: UUID(d))
+
+    def _find(self, obj: List[T], is_this: Callable[[T], bool]) -> T:
+        for o in obj:
+            if is_this(o):
+                return o
+        raise ValueError("No obj found")
