@@ -1,7 +1,10 @@
-from datetime import datetime, date
-from typing import List, Optional
-from uuid import UUID
 import attr
+from datetime import datetime, date
+from typing import List, Optional, TYPE_CHECKING
+from uuid import UUID
+
+if TYPE_CHECKING:
+    from dapodik import Dapodik
 
 
 @attr.dataclass
@@ -102,6 +105,7 @@ class PesertaDidik:
     soft_delete: Optional[int] = None
     last_sync: Optional[datetime] = None
     updater_id: Optional[UUID] = None
+    _dapodik: Optional["Dapodik"] = None
 
     def __str__(self):
         return self.nama
