@@ -1,12 +1,11 @@
+import attr
 from datetime import datetime
 from typing import Optional
 
-import attr
-
 
 @attr.dataclass(frozen=True, slots=True)
 class JenisRombel:
-    jenis_rombel: str
+    jenis_rombel: int
     nm_jenis_rombel: str
     create_date: datetime
     last_update: datetime
